#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         pg_name postgresql13%{nil}
%define         ext_name pg_cron
%{pg_version_from_name}

Name:           %{pg_name}-%{ext_name}
Version:        1.5.2
Release:        1.7
Summary:        PostgreSQL module for simple job schedule
License:        PostgreSQL
Group:          Productivity/Databases/Servers
URL:            https://github.com/citusdata/pg_cron
Source:         https://github.com/citusdata/pg_cron/archive/refs/tags/v%{version}.tar.gz#/%{ext_name}-%{version}.tar.gz
BuildRequires:  %{pg_name}-llvmjit-devel
%pg_server_requires
%if "%{pg_name}" == ""
Name:           %{ext_name}
ExclusiveArch:  do_not_build
%endif

%description
%{ext_name} is a simple cron-based job scheduler for PostgreSQL (9.5 or higher)
that runs inside the database as an extension. It uses the same syntax as
regular cron, but it allows you to schedule PostgreSQL commands directly from
the database.

%prep
%autosetup -p1 -n %{ext_name}-%{version}

%build
%make_pgxs

%install
%make_install

%post
%{_datadir}/postgresql/install-alternatives %{pg_version}

%postun
%{_datadir}/postgresql/install-alternatives %{pg_version}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{pg_config_sharedir}/extension/%{ext_name}*
%{pg_config_pkglibdir}/%{ext_name}.so
%if %{postgresql_has_llvm}
%{pg_config_pkglibdir}/bitcode/*
%endif

%changelog
* Wed Apr 19 2023 Reinhard Max <max@suse.com>
- PostgreSQL 10 is EOL.
* Sat Apr  8 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 1.5.2
  - Fixes a bug that caused crashes after upgrading binaries to
    1.5, by Polina Bungina
* Fri Feb 10 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 1.5.1
  - Fixes a bug that caused incorrect parsing of some crons schedules
* Tue Feb  7 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 1.5.0
  - Adds the possibility of scheduling a job with a 1-59 second
    interval
  - Adds a cron.timezone setting to configure the timezone of cron
    schedules
  - Removes pg_stat_activity reporting of internal pg_cron metadata
    queries
  - Fixes a bug that caused issues with long job names
  - Fixes a bug that caused inactive @reboot jobs to still run
  - Fixes a bug that could limit concurrency for background workers
  - Fixes a bug that prevented compiling on ARM
  - Fixes regression tests for PostgreSQL <= 12
* Tue Jan 31 2023 Marcus Rueckert <mrueckert@suse.de>
- enable pg 15
* Sun Jan  1 2023 Andrey Karepin <egdfree@opensuse.org>
- drop patch pg_cron-32bit-compat.patch
- update to 1.4.2
  * Fixes a bug that could lead to privilege escalation if users can
    trigger CREATE EXTENSION
  * Add compatibility for PostgreSQL 15 beta
  * Fixes a bug that could cause unschedule to crash
  * Ensures that cron.max_running_jobs is not higher than possible
    connection count
* Mon Apr  4 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update pg_cron-32bit-compat.patch to be actually the upstream
  commit from https://github.com/citusdata/pg_cron/pull/159.
* Mon Apr  4 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add pg_cron-32bit-compat.patch: Fix build on archs where %%ld does
  not equal to long long int (eg 32bit arches).
* Thu Dec  2 2021 Marcus Rueckert <mrueckert@suse.de>
- fix postgresql_has_llvm usage
* Tue Nov 30 2021 Marcus Rueckert <mrueckert@suse.de>
- switch to %%{pg_name}-llvmjit-devel
* Sun Nov 14 2021 Marcus Rueckert <mrueckert@suse.de>
- port to postgresql macros
* Sun Sep 26 2021 Andrey Karepin <egdfree@opensuse.org>
- update to 1.4.1
  * Fixes PostgreSQL 11- support
* Sat Sep 18 2021 Andrey Karepin <egdfree@opensuse.org>
- update to 1.4.0
  * Adds a cron.alter_job function to change job properties, by
    Bertrand Drouvot
  * Adds a cron.log_min_messages setting to control log_min_messages
    in pg_cron launcher, by Bertrand Drouvot
  * Adds a cron.enable_superuser_jobs setting to disallow superuser
    jobs
  * Fixes a bug that could cause jobs to hang when using
    cron.use_background_workers, by Bertrand Drouvot
  * Fixes a small memory allocation bug, by @mrdrivingduck
  * PostgreSQL 14 is supported (no changes were needed)
* Wed Jun 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do no longer build postgresql95 and postgresql96 flavors on
  Tumbleweed: those two postgresql vesions are EOL and will be
  dropped.
* Mon Mar 29 2021 Andrey Karepin <egdfree@opensuse.org>
- update to 1.3.1
  * Fixes a memory leak
* Wed Oct  7 2020 Andrey Karepin <egdfree@opensuse.org>
- update to 1.3.0
  * Background worker support by Bertrand Drouvot
  * Audit table support by Bertrand Drouvot
  * PostgreSQL 13 support by Alexander Kukushkin
  * Schedule jobs by name
  * Fixes a bug that could cause cron.schedule to crash with long
    schedules
  * Fixes a bug that could cause cron.schedule to get into an infinite
    loop
  * Fixes a bug that caused overlapping runs not to start
- adding postgresql13 to _multibuild
* Thu Jun  4 2020 Reinhard Max <max@suse.com>
- Disable LLVM on SLE builds.
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- supplement the llvmjit subpackage with the llvmjit main package
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- adding postgresql12 to _multibuild
* Sat Aug 31 2019 Andrey Karepin <egdfree@opensuse.org>
- update to 1.2.0
  * PostgreSQL 12 support by dverite
  * Fixes a bug that caused the cron.job table to not appear in pg_dump
* Sun Apr 21 2019 Andrey Karepin <egdfree@opensuse.org>
- update to 1.1.4
  * Adds a cron.host setting to make the postgres host configurable
  * Fixes a bug that could cause segmentation fault after cron.unschedule
* Sat Jan 19 2019 Andrey Karepin <egdfree@opensuse.org>
- fix build with PostgreSQL 11 and extract just-in-time compiling
  parts to llvmjit subpackage
* Thu Jan 17 2019 Andrey Karepin <egdfree@opensuse.org>
- initial
